# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/marti_nav_msgs/msg/tracked_object.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.builtin_interfaces.msg import duration_pb2 as make87__messages__ros2_dot_humble_dot_builtin__interfaces_dot_msg_dot_duration__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import point_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_point__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import pose_with_covariance_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_pose__with__covariance__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import twist_with_covariance_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_twist__with__covariance__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import vector3_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_vector3__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCmake87_messages_ros2/humble/marti_nav_msgs/msg/tracked_object.proto\x12.make87_messages_ros2.humble.marti_nav_msgs.msg\x1a!make87_messages/core/header.proto\x1a\x41make87_messages_ros2/humble/builtin_interfaces/msg/duration.proto\x1a\x39make87_messages_ros2/humble/geometry_msgs/msg/point.proto\x1aHmake87_messages_ros2/humble/geometry_msgs/msg/pose_with_covariance.proto\x1aImake87_messages_ros2/humble/geometry_msgs/msg/twist_with_covariance.proto\x1a;make87_messages_ros2/humble/geometry_msgs/msg/vector3.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\xdf\x06\n\rTrackedObject\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12\n\n\x02id\x18\x03 \x01(\r\x12O\n\x04pose\x18\x04 \x01(\x0b\x32\x41.make87_messages_ros2.humble.geometry_msgs.msg.PoseWithCovariance\x12T\n\x08velocity\x18\x05 \x01(\x0b\x32\x42.make87_messages_ros2.humble.geometry_msgs.msg.TwistWithCovariance\x12S\n\x13linear_acceleration\x18\x06 \x01(\x0b\x32\x36.make87_messages_ros2.humble.geometry_msgs.msg.Vector3\x12&\n\x1elinear_acceleration_covariance\x18\x07 \x03(\x01\x12\x45\n\x07polygon\x18\x08 \x03(\x0b\x32\x34.make87_messages_ros2.humble.geometry_msgs.msg.Point\x12\x0e\n\x06length\x18\t \x01(\x02\x12\x16\n\x0elength_quality\x18\n \x01(\x02\x12\r\n\x05width\x18\x0b \x01(\x02\x12\x15\n\rwidth_quality\x18\x0c \x01(\x02\x12\x16\n\x0e\x63lassification\x18\r \x01(\r\x12\x1e\n\x16\x63lassification_quality\x18\x0e \x01(\x02\x12\x1d\n\x15\x65xistence_probability\x18\x0f \x01(\x02\x12R\n\x0c\x61ge_duration\x18\x10 \x01(\x0b\x32<.make87_messages_ros2.humble.builtin_interfaces.msg.Duration\x12Y\n\x13prediction_duration\x18\x11 \x01(\x0b\x32<.make87_messages_ros2.humble.builtin_interfaces.msg.Duration\x12\x0e\n\x06\x61\x63tive\x18\x12 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.marti_nav_msgs.msg.tracked_object_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_TRACKEDOBJECT']._serialized_start=546
  _globals['_TRACKEDOBJECT']._serialized_end=1409
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.cartographer_ros_msgs.msg import histogram_bucket_pb2 as _histogram_bucket_pb2
from make87_messages_ros2.jazzy.cartographer_ros_msgs.msg import metric_label_pb2 as _metric_label_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Metric(_message.Message):
    __slots__ = ["type", "labels", "value", "counts_by_bucket"]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    LABELS_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    COUNTS_BY_BUCKET_FIELD_NUMBER: _ClassVar[int]
    type: int
    labels: _containers.RepeatedCompositeFieldContainer[_metric_label_pb2.MetricLabel]
    value: float
    counts_by_bucket: _containers.RepeatedCompositeFieldContainer[_histogram_bucket_pb2.HistogramBucket]
    def __init__(self, type: _Optional[int] = ..., labels: _Optional[_Iterable[_Union[_metric_label_pb2.MetricLabel, _Mapping]]] = ..., value: _Optional[float] = ..., counts_by_bucket: _Optional[_Iterable[_Union[_histogram_bucket_pb2.HistogramBucket, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.jazzy.geometry_msgs.msg import polygon_pb2 as _polygon_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PolygonInstance(_message.Message):
    __slots__ = ["polygon", "id"]
    POLYGON_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    polygon: _polygon_pb2.Polygon
    id: int
    def __init__(self, polygon: _Optional[_Union[_polygon_pb2.Polygon, _Mapping]] = ..., id: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/object_recognition_msgs/msg/recognized_object.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.geometry_msgs.msg import point_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_point__pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import pose_with_covariance_stamped_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_pose__with__covariance__stamped__pb2
from make87_messages_ros2.jazzy.object_recognition_msgs.msg import object_type_pb2 as make87__messages__ros2_dot_jazzy_dot_object__recognition__msgs_dot_msg_dot_object__type__pb2
from make87_messages_ros2.jazzy.sensor_msgs.msg import point_cloud2_pb2 as make87__messages__ros2_dot_jazzy_dot_sensor__msgs_dot_msg_dot_point__cloud2__pb2
from make87_messages_ros2.jazzy.shape_msgs.msg import mesh_pb2 as make87__messages__ros2_dot_jazzy_dot_shape__msgs_dot_msg_dot_mesh__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nNmake87_messages_ros2/jazzy/object_recognition_msgs/msg/recognized_object.proto\x12\x36make87_messages_ros2.jazzy.object_recognition_msgs.msg\x1a\x38make87_messages_ros2/jazzy/geometry_msgs/msg/point.proto\x1aOmake87_messages_ros2/jazzy/geometry_msgs/msg/pose_with_covariance_stamped.proto\x1aHmake87_messages_ros2/jazzy/object_recognition_msgs/msg/object_type.proto\x1a=make87_messages_ros2/jazzy/sensor_msgs/msg/point_cloud2.proto\x1a\x34make87_messages_ros2/jazzy/shape_msgs/msg/mesh.proto\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\xf7\x03\n\x10RecognizedObject\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12P\n\x04type\x18\x02 \x01(\x0b\x32\x42.make87_messages_ros2.jazzy.object_recognition_msgs.msg.ObjectType\x12\x12\n\nconfidence\x18\x03 \x01(\x02\x12M\n\x0cpoint_clouds\x18\x04 \x03(\x0b\x32\x37.make87_messages_ros2.jazzy.sensor_msgs.msg.PointCloud2\x12\x46\n\rbounding_mesh\x18\x05 \x01(\x0b\x32/.make87_messages_ros2.jazzy.shape_msgs.msg.Mesh\x12N\n\x11\x62ounding_contours\x18\x06 \x03(\x0b\x32\x33.make87_messages_ros2.jazzy.geometry_msgs.msg.Point\x12U\n\x04pose\x18\x07 \x01(\x0b\x32G.make87_messages_ros2.jazzy.geometry_msgs.msg.PoseWithCovarianceStampedb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.object_recognition_msgs.msg.recognized_object_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_RECOGNIZEDOBJECT']._serialized_start=523
  _globals['_RECOGNIZEDOBJECT']._serialized_end=1026
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class ResolutionInfo(_message.Message):
    __slots__ = ["resolution_start_angle", "resolution"]
    RESOLUTION_START_ANGLE_FIELD_NUMBER: _ClassVar[int]
    RESOLUTION_FIELD_NUMBER: _ClassVar[int]
    resolution_start_angle: float
    resolution: float
    def __init__(self, resolution_start_angle: _Optional[float] = ..., resolution: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rtabmap_msgs/srv/get_node_data.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.rtabmap_msgs.msg import node_pb2 as make87__messages__ros2_dot_jazzy_dot_rtabmap__msgs_dot_msg_dot_node__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?make87_messages_ros2/jazzy/rtabmap_msgs/srv/get_node_data.proto\x12+make87_messages_ros2.jazzy.rtabmap_msgs.srv\x1a\x36make87_messages_ros2/jazzy/rtabmap_msgs/msg/node.proto\"`\n\x12GetNodeDataRequest\x12\x0b\n\x03ids\x18\x01 \x03(\x05\x12\x0e\n\x06images\x18\x02 \x01(\x08\x12\x0c\n\x04scan\x18\x03 \x01(\x08\x12\x0c\n\x04grid\x18\x04 \x01(\x08\x12\x11\n\tuser_data\x18\x05 \x01(\x08\"V\n\x13GetNodeDataResponse\x12?\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x31.make87_messages_ros2.jazzy.rtabmap_msgs.msg.Nodeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rtabmap_msgs.srv.get_node_data_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETNODEDATAREQUEST']._serialized_start=168
  _globals['_GETNODEDATAREQUEST']._serialized_end=264
  _globals['_GETNODEDATARESPONSE']._serialized_start=266
  _globals['_GETNODEDATARESPONSE']._serialized_end=352
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rosapi_msgs/srv/topics_and_raw_types.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGmake87_messages_ros2/rolling/rosapi_msgs/srv/topics_and_raw_types.proto\x12,make87_messages_ros2.rolling.rosapi_msgs.srv\"\x1a\n\x18TopicsAndRawTypesRequest\"V\n\x19TopicsAndRawTypesResponse\x12\x0e\n\x06topics\x18\x01 \x03(\t\x12\r\n\x05types\x18\x02 \x03(\t\x12\x1a\n\x12typedefs_full_text\x18\x03 \x03(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rosapi_msgs.srv.topics_and_raw_types_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_TOPICSANDRAWTYPESREQUEST']._serialized_start=121
  _globals['_TOPICSANDRAWTYPESREQUEST']._serialized_end=147
  _globals['_TOPICSANDRAWTYPESRESPONSE']._serialized_start=149
  _globals['_TOPICSANDRAWTYPESRESPONSE']._serialized_end=235
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/smacc2_msgs/srv/smacc_get_transition_history.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.smacc2_msgs.msg import smacc_transition_log_entry_pb2 as make87__messages__ros2_dot_jazzy_dot_smacc2__msgs_dot_msg_dot_smacc__transition__log__entry__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nMmake87_messages_ros2/jazzy/smacc2_msgs/srv/smacc_get_transition_history.proto\x12*make87_messages_ros2.jazzy.smacc2_msgs.srv\x1aKmake87_messages_ros2/jazzy/smacc2_msgs/msg/smacc_transition_log_entry.proto\"\"\n SmaccGetTransitionHistoryRequest\"y\n!SmaccGetTransitionHistoryResponse\x12T\n\x07history\x18\x01 \x03(\x0b\x32\x43.make87_messages_ros2.jazzy.smacc2_msgs.msg.SmaccTransitionLogEntryb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.smacc2_msgs.srv.smacc_get_transition_history_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SMACCGETTRANSITIONHISTORYREQUEST']._serialized_start=202
  _globals['_SMACCGETTRANSITIONHISTORYREQUEST']._serialized_end=236
  _globals['_SMACCGETTRANSITIONHISTORYRESPONSE']._serialized_start=238
  _globals['_SMACCGETTRANSITIONHISTORYRESPONSE']._serialized_end=359
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class StreamRateRequest(_message.Message):
    __slots__ = ["header", "stream_id", "message_rate", "on_off"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    STREAM_ID_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_RATE_FIELD_NUMBER: _ClassVar[int]
    ON_OFF_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    stream_id: int
    message_rate: int
    on_off: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., stream_id: _Optional[int] = ..., message_rate: _Optional[int] = ..., on_off: bool = ...) -> None: ...

class StreamRateResponse(_message.Message):
    __slots__ = ["header"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ...) -> None: ...



from make87_messages_ros2.rolling.geometry_msgs.msg import vector3_pb2 as _vector3_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Inertia(_message.Message):
    __slots__ = ["m", "com", "ixx", "ixy", "ixz", "iyy", "iyz", "izz"]
    M_FIELD_NUMBER: _ClassVar[int]
    COM_FIELD_NUMBER: _ClassVar[int]
    IXX_FIELD_NUMBER: _ClassVar[int]
    IXY_FIELD_NUMBER: _ClassVar[int]
    IXZ_FIELD_NUMBER: _ClassVar[int]
    IYY_FIELD_NUMBER: _ClassVar[int]
    IYZ_FIELD_NUMBER: _ClassVar[int]
    IZZ_FIELD_NUMBER: _ClassVar[int]
    m: float
    com: _vector3_pb2.Vector3
    ixx: float
    ixy: float
    ixz: float
    iyy: float
    iyz: float
    izz: float
    def __init__(self, m: _Optional[float] = ..., com: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ..., ixx: _Optional[float] = ..., ixy: _Optional[float] = ..., ixz: _Optional[float] = ..., iyy: _Optional[float] = ..., iyz: _Optional[float] = ..., izz: _Optional[float] = ...) -> None: ...



from make87_messages_ros2.jazzy.actionlib_msgs.msg import goal_id_pb2 as _goal_id_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GoalStatus(_message.Message):
    __slots__ = ["goal_id", "status", "text"]
    GOAL_ID_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    TEXT_FIELD_NUMBER: _ClassVar[int]
    goal_id: _goal_id_pb2.GoalID
    status: int
    text: str
    def __init__(self, goal_id: _Optional[_Union[_goal_id_pb2.GoalID, _Mapping]] = ..., status: _Optional[int] = ..., text: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/ublox_ubx_msgs/msg/esf_sensor_status.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFmake87_messages_ros2/humble/ublox_ubx_msgs/msg/esf_sensor_status.proto\x12.make87_messages_ros2.humble.ublox_ubx_msgs.msg\x1a!make87_messages/core/header.proto\"\x95\x02\n\x0f\x45SFSensorStatus\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x18\n\x10sensor_data_type\x18\x02 \x01(\r\x12\x0c\n\x04used\x18\x03 \x01(\x08\x12\r\n\x05ready\x18\x04 \x01(\x08\x12\x14\n\x0c\x63\x61lib_status\x18\x05 \x01(\r\x12\x13\n\x0btime_status\x18\x06 \x01(\r\x12\x0c\n\x04\x66req\x18\x07 \x01(\r\x12\x16\n\x0e\x66\x61ult_bad_meas\x18\x08 \x01(\x08\x12\x16\n\x0e\x66\x61ult_bad_ttag\x18\t \x01(\x08\x12\x1a\n\x12\x66\x61ult_missing_meas\x18\n \x01(\x08\x12\x18\n\x10\x66\x61ult_noisy_meas\x18\x0b \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.ublox_ubx_msgs.msg.esf_sensor_status_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ESFSENSORSTATUS']._serialized_start=158
  _globals['_ESFSENSORSTATUS']._serialized_end=435
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.visualization_msgs.msg import interactive_marker_pb2 as _interactive_marker_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class InteractiveMarkerInit(_message.Message):
    __slots__ = ["header", "server_id", "seq_num", "markers"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SERVER_ID_FIELD_NUMBER: _ClassVar[int]
    SEQ_NUM_FIELD_NUMBER: _ClassVar[int]
    MARKERS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    server_id: str
    seq_num: int
    markers: _containers.RepeatedCompositeFieldContainer[_interactive_marker_pb2.InteractiveMarker]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., server_id: _Optional[str] = ..., seq_num: _Optional[int] = ..., markers: _Optional[_Iterable[_Union[_interactive_marker_pb2.InteractiveMarker, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/test_interface_files/srv/basic_types.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGmake87_messages_ros2/rolling/test_interface_files/srv/basic_types.proto\x12\x35make87_messages_ros2.rolling.test_interface_files.srv\"\xbd\x02\n\x11\x42\x61sicTypesRequest\x12\x12\n\nbool_value\x18\x01 \x01(\x08\x12\x12\n\nbyte_value\x18\x02 \x01(\r\x12\x12\n\nchar_value\x18\x03 \x01(\x05\x12\x15\n\rfloat32_value\x18\x04 \x01(\x02\x12\x15\n\rfloat64_value\x18\x05 \x01(\x01\x12\x12\n\nint8_value\x18\x06 \x01(\x05\x12\x13\n\x0buint8_value\x18\x07 \x01(\r\x12\x13\n\x0bint16_value\x18\x08 \x01(\x05\x12\x14\n\x0cuint16_value\x18\t \x01(\r\x12\x13\n\x0bint32_value\x18\n \x01(\x05\x12\x14\n\x0cuint32_value\x18\x0b \x01(\r\x12\x13\n\x0bint64_value\x18\x0c \x01(\x03\x12\x14\n\x0cuint64_value\x18\r \x01(\x04\x12\x14\n\x0cstring_value\x18\x0e \x01(\t\"\xbe\x02\n\x12\x42\x61sicTypesResponse\x12\x12\n\nbool_value\x18\x01 \x01(\x08\x12\x12\n\nbyte_value\x18\x02 \x01(\r\x12\x12\n\nchar_value\x18\x03 \x01(\x05\x12\x15\n\rfloat32_value\x18\x04 \x01(\x02\x12\x15\n\rfloat64_value\x18\x05 \x01(\x01\x12\x12\n\nint8_value\x18\x06 \x01(\x05\x12\x13\n\x0buint8_value\x18\x07 \x01(\r\x12\x13\n\x0bint16_value\x18\x08 \x01(\x05\x12\x14\n\x0cuint16_value\x18\t \x01(\r\x12\x13\n\x0bint32_value\x18\n \x01(\x05\x12\x14\n\x0cuint32_value\x18\x0b \x01(\r\x12\x13\n\x0bint64_value\x18\x0c \x01(\x03\x12\x14\n\x0cuint64_value\x18\r \x01(\x04\x12\x14\n\x0cstring_value\x18\x0e \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.test_interface_files.srv.basic_types_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_BASICTYPESREQUEST']._serialized_start=131
  _globals['_BASICTYPESREQUEST']._serialized_end=448
  _globals['_BASICTYPESRESPONSE']._serialized_start=451
  _globals['_BASICTYPESRESPONSE']._serialized_end=769
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Speed(_message.Message):
    __slots__ = ["header", "module_name", "speed", "acceleration_limit", "deceleration_limit"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    MODULE_NAME_FIELD_NUMBER: _ClassVar[int]
    SPEED_FIELD_NUMBER: _ClassVar[int]
    ACCELERATION_LIMIT_FIELD_NUMBER: _ClassVar[int]
    DECELERATION_LIMIT_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    module_name: str
    speed: float
    acceleration_limit: float
    deceleration_limit: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., module_name: _Optional[str] = ..., speed: _Optional[float] = ..., acceleration_limit: _Optional[float] = ..., deceleration_limit: _Optional[float] = ...) -> None: ...



from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class LkaReferencePoints(_message.Message):
    __slots__ = ["header", "ref_point_1_position", "ref_point_1_distance", "ref_point_1_validity", "ref_point_2_position", "ref_point_2_distance", "ref_point_2_validity"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    REF_POINT_1_POSITION_FIELD_NUMBER: _ClassVar[int]
    REF_POINT_1_DISTANCE_FIELD_NUMBER: _ClassVar[int]
    REF_POINT_1_VALIDITY_FIELD_NUMBER: _ClassVar[int]
    REF_POINT_2_POSITION_FIELD_NUMBER: _ClassVar[int]
    REF_POINT_2_DISTANCE_FIELD_NUMBER: _ClassVar[int]
    REF_POINT_2_VALIDITY_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ref_point_1_position: float
    ref_point_1_distance: float
    ref_point_1_validity: bool
    ref_point_2_position: float
    ref_point_2_distance: float
    ref_point_2_validity: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ref_point_1_position: _Optional[float] = ..., ref_point_1_distance: _Optional[float] = ..., ref_point_1_validity: bool = ..., ref_point_2_position: _Optional[float] = ..., ref_point_2_distance: _Optional[float] = ..., ref_point_2_validity: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/mobileye_560_660_msgs/msg/lka_lane.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/rolling/mobileye_560_660_msgs/msg/lka_lane.proto\x12\x36make87_messages_ros2.rolling.mobileye_560_660_msgs.msg\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\xe0\x02\n\x07LkaLane\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12\x11\n\tlane_type\x18\x02 \x01(\r\x12\x0f\n\x07quality\x18\x03 \x01(\r\x12\x14\n\x0cmodel_degree\x18\x04 \x01(\r\x12\x1d\n\x15position_parameter_c0\x18\x05 \x01(\x01\x12\x1e\n\x16\x63urvature_parameter_c2\x18\x06 \x01(\x01\x12)\n!curvature_derivative_parameter_c3\x18\x07 \x01(\x01\x12\x15\n\rmarking_width\x18\x08 \x01(\x02\x12\"\n\x1aheading_angle_parameter_c1\x18\t \x01(\x01\x12\x12\n\nview_range\x18\n \x01(\x02\x12\x1f\n\x17view_range_availability\x18\x0b \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.mobileye_560_660_msgs.msg.lka_lane_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_LKALANE']._serialized_start=186
  _globals['_LKALANE']._serialized_end=538
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class VelocityReport(_message.Message):
    __slots__ = ["header", "longitudinal_velocity", "lateral_velocity", "heading_rate"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    LONGITUDINAL_VELOCITY_FIELD_NUMBER: _ClassVar[int]
    LATERAL_VELOCITY_FIELD_NUMBER: _ClassVar[int]
    HEADING_RATE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    longitudinal_velocity: float
    lateral_velocity: float
    heading_rate: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., longitudinal_velocity: _Optional[float] = ..., lateral_velocity: _Optional[float] = ..., heading_rate: _Optional[float] = ...) -> None: ...



from make87_messages_ros2.jazzy.std_msgs.msg import color_rgba_pb2 as _color_rgba_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class OverlayText(_message.Message):
    __slots__ = ["action", "width", "height", "horizontal_distance", "vertical_distance", "horizontal_alignment", "vertical_alignment", "bg_color", "line_width", "text_size", "font", "fg_color", "text"]
    ACTION_FIELD_NUMBER: _ClassVar[int]
    WIDTH_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    HORIZONTAL_DISTANCE_FIELD_NUMBER: _ClassVar[int]
    VERTICAL_DISTANCE_FIELD_NUMBER: _ClassVar[int]
    HORIZONTAL_ALIGNMENT_FIELD_NUMBER: _ClassVar[int]
    VERTICAL_ALIGNMENT_FIELD_NUMBER: _ClassVar[int]
    BG_COLOR_FIELD_NUMBER: _ClassVar[int]
    LINE_WIDTH_FIELD_NUMBER: _ClassVar[int]
    TEXT_SIZE_FIELD_NUMBER: _ClassVar[int]
    FONT_FIELD_NUMBER: _ClassVar[int]
    FG_COLOR_FIELD_NUMBER: _ClassVar[int]
    TEXT_FIELD_NUMBER: _ClassVar[int]
    action: int
    width: int
    height: int
    horizontal_distance: int
    vertical_distance: int
    horizontal_alignment: int
    vertical_alignment: int
    bg_color: _color_rgba_pb2.ColorRGBA
    line_width: int
    text_size: float
    font: str
    fg_color: _color_rgba_pb2.ColorRGBA
    text: str
    def __init__(self, action: _Optional[int] = ..., width: _Optional[int] = ..., height: _Optional[int] = ..., horizontal_distance: _Optional[int] = ..., vertical_distance: _Optional[int] = ..., horizontal_alignment: _Optional[int] = ..., vertical_alignment: _Optional[int] = ..., bg_color: _Optional[_Union[_color_rgba_pb2.ColorRGBA, _Mapping]] = ..., line_width: _Optional[int] = ..., text_size: _Optional[float] = ..., font: _Optional[str] = ..., fg_color: _Optional[_Union[_color_rgba_pb2.ColorRGBA, _Mapping]] = ..., text: _Optional[str] = ...) -> None: ...



from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class UBXNavOdo(_message.Message):
    __slots__ = ["header", "version", "itow", "distance", "total_distance", "distance_std"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    ITOW_FIELD_NUMBER: _ClassVar[int]
    DISTANCE_FIELD_NUMBER: _ClassVar[int]
    TOTAL_DISTANCE_FIELD_NUMBER: _ClassVar[int]
    DISTANCE_STD_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    version: int
    itow: int
    distance: int
    total_distance: int
    distance_std: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., version: _Optional[int] = ..., itow: _Optional[int] = ..., distance: _Optional[int] = ..., total_distance: _Optional[int] = ..., distance_std: _Optional[int] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import vector3_pb2 as _vector3_pb2
from make87_messages_ros2.humble.marine_acoustic_msgs.msg import ping_info_pb2 as _ping_info_pb2
from make87_messages_ros2.humble.marine_acoustic_msgs.msg import sonar_image_data_pb2 as _sonar_image_data_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ProjectedSonarImage(_message.Message):
    __slots__ = ["header", "ros2_header", "ping_info", "beam_directions", "ranges", "image"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    PING_INFO_FIELD_NUMBER: _ClassVar[int]
    BEAM_DIRECTIONS_FIELD_NUMBER: _ClassVar[int]
    RANGES_FIELD_NUMBER: _ClassVar[int]
    IMAGE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    ping_info: _ping_info_pb2.PingInfo
    beam_directions: _containers.RepeatedCompositeFieldContainer[_vector3_pb2.Vector3]
    ranges: _containers.RepeatedScalarFieldContainer[float]
    image: _sonar_image_data_pb2.SonarImageData
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., ping_info: _Optional[_Union[_ping_info_pb2.PingInfo, _Mapping]] = ..., beam_directions: _Optional[_Iterable[_Union[_vector3_pb2.Vector3, _Mapping]]] = ..., ranges: _Optional[_Iterable[float]] = ..., image: _Optional[_Union[_sonar_image_data_pb2.SonarImageData, _Mapping]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.sensor_msgs.msg import nav_sat_fix_pb2 as _nav_sat_fix_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AddStaticTransformGpsRequest(_message.Message):
    __slots__ = ["header", "frame_id", "child_frame_id", "gps_position", "azimuth", "elevation", "bank"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    FRAME_ID_FIELD_NUMBER: _ClassVar[int]
    CHILD_FRAME_ID_FIELD_NUMBER: _ClassVar[int]
    GPS_POSITION_FIELD_NUMBER: _ClassVar[int]
    AZIMUTH_FIELD_NUMBER: _ClassVar[int]
    ELEVATION_FIELD_NUMBER: _ClassVar[int]
    BANK_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    frame_id: str
    child_frame_id: str
    gps_position: _nav_sat_fix_pb2.NavSatFix
    azimuth: float
    elevation: float
    bank: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., frame_id: _Optional[str] = ..., child_frame_id: _Optional[str] = ..., gps_position: _Optional[_Union[_nav_sat_fix_pb2.NavSatFix, _Mapping]] = ..., azimuth: _Optional[float] = ..., elevation: _Optional[float] = ..., bank: _Optional[float] = ...) -> None: ...

class AddStaticTransformGpsResponse(_message.Message):
    __slots__ = ["header", "success"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    success: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., success: bool = ...) -> None: ...



from make87_messages_ros2.jazzy.delphi_esr_msgs.msg import esr_track_motion_power_track_pb2 as _esr_track_motion_power_track_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class EsrTrackMotionPowerGroup(_message.Message):
    __slots__ = ["header", "canmsg", "rolling_count_2", "can_id_group", "tracks"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    CANMSG_FIELD_NUMBER: _ClassVar[int]
    ROLLING_COUNT_2_FIELD_NUMBER: _ClassVar[int]
    CAN_ID_GROUP_FIELD_NUMBER: _ClassVar[int]
    TRACKS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    canmsg: str
    rolling_count_2: int
    can_id_group: int
    tracks: _containers.RepeatedCompositeFieldContainer[_esr_track_motion_power_track_pb2.EsrTrackMotionPowerTrack]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., canmsg: _Optional[str] = ..., rolling_count_2: _Optional[int] = ..., can_id_group: _Optional[int] = ..., tracks: _Optional[_Iterable[_Union[_esr_track_motion_power_track_pb2.EsrTrackMotionPowerTrack, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DesiredDestination(_message.Message):
    __slots__ = ["header", "msg_counter", "valid", "latitude", "longitude"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    MSG_COUNTER_FIELD_NUMBER: _ClassVar[int]
    VALID_FIELD_NUMBER: _ClassVar[int]
    LATITUDE_FIELD_NUMBER: _ClassVar[int]
    LONGITUDE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    msg_counter: int
    valid: int
    latitude: float
    longitude: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., msg_counter: _Optional[int] = ..., valid: _Optional[int] = ..., latitude: _Optional[float] = ..., longitude: _Optional[float] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class SensorPerformanceMetric(_message.Message):
    __slots__ = ["name", "sim_update_rate", "real_update_rate", "fps"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    SIM_UPDATE_RATE_FIELD_NUMBER: _ClassVar[int]
    REAL_UPDATE_RATE_FIELD_NUMBER: _ClassVar[int]
    FPS_FIELD_NUMBER: _ClassVar[int]
    name: str
    sim_update_rate: float
    real_update_rate: float
    fps: float
    def __init__(self, name: _Optional[str] = ..., sim_update_rate: _Optional[float] = ..., real_update_rate: _Optional[float] = ..., fps: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/delphi_srr_msgs/msg/srr_debug3.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@make87_messages_ros2/humble/delphi_srr_msgs/msg/srr_debug3.proto\x12/make87_messages_ros2.humble.delphi_srr_msgs.msg\x1a!make87_messages/core/header.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\xfa\n\n\tSrrDebug3\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12\x1a\n\x12timer_create_error\x18\x03 \x01(\x08\x12\x1b\n\x13thread_create_error\x18\x04 \x01(\x08\x12\x1d\n\x15\x61rm_calibration_error\x18\x05 \x01(\x08\x12\x15\n\rspi_fee_error\x18\x06 \x01(\x08\x12\x16\n\x0espi_comm_error\x18\x07 \x01(\x08\x12\x1a\n\x12socket_write_error\x18\x08 \x01(\x08\x12!\n\x19\x64sp_cal_obsolete_62_error\x18\t \x01(\x08\x12\x19\n\x11socket_read_error\x18\n \x01(\x08\x12\x19\n\x11socket_init_error\x18\x0b \x01(\x08\x12\x19\n\x11signal_wait_error\x18\x0c \x01(\x08\x12\x19\n\x11signal_send_error\x18\r \x01(\x08\x12\x1b\n\x13signal_create_error\x18\x0e \x01(\x08\x12\x1e\n\x16shared_mem_write_error\x18\x0f \x01(\x08\x12\x1d\n\x15shared_mem_read_error\x18\x10 \x01(\x08\x12\x1f\n\x17shared_mem_config_error\x18\x11 \x01(\x08\x12\x1c\n\x14share_mem_init_error\x18\x12 \x01(\x08\x12\x16\n\x0eram_test_error\x18\x13 \x01(\x08\x12\x12\n\nnum_errors\x18\x14 \x01(\x08\x12\x19\n\x11mmap_memory_error\x18\x15 \x01(\x08\x12\x18\n\x10isr_attach_error\x18\x16 \x01(\x08\x12\x1b\n\x13ipc_drv_write_error\x18\x17 \x01(\x08\x12\x1d\n\x15ipc_drv_trigger_error\x18\x18 \x01(\x08\x12\x1a\n\x12ipc_drv_sync_error\x18\x19 \x01(\x08\x12\x1a\n\x12ipc_drv_read_error\x18\x1a \x01(\x08\x12\x1a\n\x12ipc_drv_init_error\x18\x1b \x01(\x08\x12\x1e\n\x16interrupt_enable_error\x18\x1c \x01(\x08\x12\x18\n\x10hil_format_error\x18\x1d \x01(\x08\x12\x1e\n\x16\x66lash_filesystem_error\x18\x1e \x01(\x08\x12\x12\n\nerror_none\x18\x1f \x01(\x08\x12\x1b\n\x13\x64sp_load_read_error\x18  \x01(\x08\x12\x1b\n\x13\x64sp_load_open_error\x18! \x01(\x08\x12\x1e\n\x16\x64sp_load_address_error\x18\" \x01(\x08\x12\x1b\n\x13\x64sp_isp_write_error\x18# \x01(\x08\x12\x1a\n\x12\x64sp_ipc_read_error\x18$ \x01(\x08\x12\x14\n\x0c\x64sp_ipc_init\x18% \x01(\x08\x12\x16\n\x0e\x64sp_init_error\x18& \x01(\x08\x12\x1b\n\x13\x64sp_drv_start_error\x18\' \x01(\x08\x12\x1a\n\x12\x64sp_drv_load_error\x18( \x01(\x08\x12\x1a\n\x12\x64sp_drv_init_error\x18) \x01(\x08\x12\x1b\n\x13\x64sp_drv_init2_error\x18* \x01(\x08\x12\x1b\n\x13\x64sp_drv_init1_error\x18+ \x01(\x08\x12\x1d\n\x15\x64sp_calibration_error\x18, \x01(\x08\x12\x15\n\rcan_xmt_error\x18- \x01(\x08\x12\x15\n\rcan_rcv_error\x18. \x01(\x08\x12\x1a\n\x12\x63\x61n_hardware_error\x18/ \x01(\x08\x12\x13\n\x0b\x61lways_true\x18\x30 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.delphi_srr_msgs.msg.srr_debug3_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SRRDEBUG3']._serialized_start=208
  _globals['_SRRDEBUG3']._serialized_end=1610
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/vision_msgs/msg/bounding_box2_d.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.vision_msgs.msg import pose2_d_pb2 as make87__messages__ros2_dot_jazzy_dot_vision__msgs_dot_msg_dot_pose2__d__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@make87_messages_ros2/jazzy/vision_msgs/msg/bounding_box2_d.proto\x12*make87_messages_ros2.jazzy.vision_msgs.msg\x1a\x38make87_messages_ros2/jazzy/vision_msgs/msg/pose2_d.proto\"s\n\rBoundingBox2D\x12\x42\n\x06\x63\x65nter\x18\x01 \x01(\x0b\x32\x32.make87_messages_ros2.jazzy.vision_msgs.msg.Pose2D\x12\x0e\n\x06size_x\x18\x02 \x01(\x01\x12\x0e\n\x06size_y\x18\x03 \x01(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.vision_msgs.msg.bounding_box2_d_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_BOUNDINGBOX2D']._serialized_start=170
  _globals['_BOUNDINGBOX2D']._serialized_end=285
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/test_interface_files/msg/w_strings.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/rolling/test_interface_files/msg/w_strings.proto\x12\x35make87_messages_ros2.rolling.test_interface_files.msg\"\xea\x01\n\x08WStrings\x12\x15\n\rwstring_value\x18\x01 \x01(\t\x12\x1e\n\x16wstring_value_default1\x18\x02 \x01(\t\x12\x1e\n\x16wstring_value_default2\x18\x03 \x01(\t\x12\x1e\n\x16wstring_value_default3\x18\x04 \x01(\t\x12\x19\n\x11\x61rray_of_wstrings\x18\x05 \x03(\t\x12$\n\x1c\x62ounded_sequence_of_wstrings\x18\x06 \x03(\t\x12&\n\x1eunbounded_sequence_of_wstrings\x18\x07 \x03(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.test_interface_files.msg.w_strings_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_WSTRINGS']._serialized_start=129
  _globals['_WSTRINGS']._serialized_end=363
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PedestrianImageID(_message.Message):
    __slots__ = ["header", "ros2_header", "pixel_x", "pixel_y", "image_width", "image_height"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    PIXEL_X_FIELD_NUMBER: _ClassVar[int]
    PIXEL_Y_FIELD_NUMBER: _ClassVar[int]
    IMAGE_WIDTH_FIELD_NUMBER: _ClassVar[int]
    IMAGE_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    pixel_x: int
    pixel_y: int
    image_width: int
    image_height: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., pixel_x: _Optional[int] = ..., pixel_y: _Optional[int] = ..., image_width: _Optional[int] = ..., image_height: _Optional[int] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class ToolDataMsg(_message.Message):
    __slots__ = ["analog_input_range2", "analog_input_range3", "analog_input2", "analog_input3", "tool_voltage_48v", "tool_output_voltage", "tool_current", "tool_temperature", "tool_mode"]
    ANALOG_INPUT_RANGE2_FIELD_NUMBER: _ClassVar[int]
    ANALOG_INPUT_RANGE3_FIELD_NUMBER: _ClassVar[int]
    ANALOG_INPUT2_FIELD_NUMBER: _ClassVar[int]
    ANALOG_INPUT3_FIELD_NUMBER: _ClassVar[int]
    TOOL_VOLTAGE_48V_FIELD_NUMBER: _ClassVar[int]
    TOOL_OUTPUT_VOLTAGE_FIELD_NUMBER: _ClassVar[int]
    TOOL_CURRENT_FIELD_NUMBER: _ClassVar[int]
    TOOL_TEMPERATURE_FIELD_NUMBER: _ClassVar[int]
    TOOL_MODE_FIELD_NUMBER: _ClassVar[int]
    analog_input_range2: int
    analog_input_range3: int
    analog_input2: float
    analog_input3: float
    tool_voltage_48v: float
    tool_output_voltage: int
    tool_current: float
    tool_temperature: float
    tool_mode: int
    def __init__(self, analog_input_range2: _Optional[int] = ..., analog_input_range3: _Optional[int] = ..., analog_input2: _Optional[float] = ..., analog_input3: _Optional[float] = ..., tool_voltage_48v: _Optional[float] = ..., tool_output_voltage: _Optional[int] = ..., tool_current: _Optional[float] = ..., tool_temperature: _Optional[float] = ..., tool_mode: _Optional[int] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class LogRequestDataRequest(_message.Message):
    __slots__ = ["header", "id", "offset", "count"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    COUNT_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    id: int
    offset: int
    count: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., id: _Optional[int] = ..., offset: _Optional[int] = ..., count: _Optional[int] = ...) -> None: ...

class LogRequestDataResponse(_message.Message):
    __slots__ = ["header", "success"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    success: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., success: bool = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class DispatchAck(_message.Message):
    __slots__ = ["dispatch_id", "success", "errors"]
    DISPATCH_ID_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    ERRORS_FIELD_NUMBER: _ClassVar[int]
    dispatch_id: int
    success: bool
    errors: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, dispatch_id: _Optional[int] = ..., success: bool = ..., errors: _Optional[_Iterable[str]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/vision_msgs/msg/object_hypothesis_with_pose.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geometry_msgs.msg import pose_with_covariance_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_pose__with__covariance__pb2
from make87_messages_ros2.rolling.vision_msgs.msg import object_hypothesis_pb2 as make87__messages__ros2_dot_rolling_dot_vision__msgs_dot_msg_dot_object__hypothesis__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nNmake87_messages_ros2/rolling/vision_msgs/msg/object_hypothesis_with_pose.proto\x12,make87_messages_ros2.rolling.vision_msgs.msg\x1aImake87_messages_ros2/rolling/geometry_msgs/msg/pose_with_covariance.proto\x1a\x44make87_messages_ros2/rolling/vision_msgs/msg/object_hypothesis.proto\"\xc0\x01\n\x18ObjectHypothesisWithPose\x12R\n\nhypothesis\x18\x01 \x01(\x0b\x32>.make87_messages_ros2.rolling.vision_msgs.msg.ObjectHypothesis\x12P\n\x04pose\x18\x02 \x01(\x0b\x32\x42.make87_messages_ros2.rolling.geometry_msgs.msg.PoseWithCovarianceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.vision_msgs.msg.object_hypothesis_with_pose_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_OBJECTHYPOTHESISWITHPOSE']._serialized_start=274
  _globals['_OBJECTHYPOTHESISWITHPOSE']._serialized_end=466
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class NavTIMEUTC(_message.Message):
    __slots__ = ["header", "i_tow", "t_acc", "nano", "year", "month", "day", "hour", "min", "sec", "valid"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    I_TOW_FIELD_NUMBER: _ClassVar[int]
    T_ACC_FIELD_NUMBER: _ClassVar[int]
    NANO_FIELD_NUMBER: _ClassVar[int]
    YEAR_FIELD_NUMBER: _ClassVar[int]
    MONTH_FIELD_NUMBER: _ClassVar[int]
    DAY_FIELD_NUMBER: _ClassVar[int]
    HOUR_FIELD_NUMBER: _ClassVar[int]
    MIN_FIELD_NUMBER: _ClassVar[int]
    SEC_FIELD_NUMBER: _ClassVar[int]
    VALID_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    i_tow: int
    t_acc: int
    nano: int
    year: int
    month: int
    day: int
    hour: int
    min: int
    sec: int
    valid: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., i_tow: _Optional[int] = ..., t_acc: _Optional[int] = ..., nano: _Optional[int] = ..., year: _Optional[int] = ..., month: _Optional[int] = ..., day: _Optional[int] = ..., hour: _Optional[int] = ..., min: _Optional[int] = ..., sec: _Optional[int] = ..., valid: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ibeo_msgs/msg/ibeo_data_header.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_jazzy_dot_builtin__interfaces_dot_msg_dot_time__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?make87_messages_ros2/jazzy/ibeo_msgs/msg/ibeo_data_header.proto\x12(make87_messages_ros2.jazzy.ibeo_msgs.msg\x1a<make87_messages_ros2/jazzy/builtin_interfaces/msg/time.proto\"\xb6\x01\n\x0eIbeoDataHeader\x12\x1d\n\x15previous_message_size\x18\x01 \x01(\r\x12\x14\n\x0cmessage_size\x18\x02 \x01(\r\x12\x11\n\tdevice_id\x18\x03 \x01(\r\x12\x14\n\x0c\x64\x61ta_type_id\x18\x04 \x01(\r\x12\x46\n\x05stamp\x18\x05 \x01(\x0b\x32\x37.make87_messages_ros2.jazzy.builtin_interfaces.msg.Timeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ibeo_msgs.msg.ibeo_data_header_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_IBEODATAHEADER']._serialized_start=172
  _globals['_IBEODATAHEADER']._serialized_end=354
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.builtin_interfaces.msg import time_pb2 as _time_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Clock(_message.Message):
    __slots__ = ["clock"]
    CLOCK_FIELD_NUMBER: _ClassVar[int]
    clock: _time_pb2.Time
    def __init__(self, clock: _Optional[_Union[_time_pb2.Time, _Mapping]] = ...) -> None: ...
